import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:sizer/sizer.dart';

import 'core/router.dart';

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Sizer(
      builder: (context, orientation, deviceType) {
        return MaterialApp(
          /* localizationsDelegates: [
            GlobalMaterialLocalizations.delegate,
            GlobalWidgetsLocalizations.delegate,
            GlobalCupertinoLocalizations.delegate,
          ],*/
          supportedLocales: [
            Locale('es'), // Spanish
          ],
          theme: ThemeData(
            brightness: Brightness.light,
            scaffoldBackgroundColor: Colors.grey.shade900,
            primaryColor: COLOR_CONST.PRIMARY,
            hoverColor: COLOR_CONST.GRAY2,
            fontFamily: 'Oswald',
            colorScheme: ColorScheme.fromSwatch()
                .copyWith(secondary: COLOR_CONST.PRIMARY),
          ),
          onGenerateRoute: AppRouter.generateRoute,
          home: BlocBuilder<AuthenticationBloc, AuthenticationState>(
            builder: (context, state) {
              if (state is Uninitialized) {
                return SplashScreen();
              } else if (state is Unauthenticated) {
                return LoginScreen();
              } else if (state is Authenticated) {
                return HomeScreen();
              }

              return Container(
                child: Center(child: Text('Unhandle State $state')),
              );
            },
          ),
        );
      },
    );
  }

  static Widget runWidget() {
    return FutureBuilder(
      future: Future.sync(() => true),
      builder: (context, snapshot) {
        if (snapshot.hasData) {
          final UserRepository userRepository = UserRepository();
          /*final TimerRepository timerRepository = TimerRepository();
          final HomeRepository homeRepository = HomeRepository();
          final ShowRepository showRepository = ShowRepository();
          final ProductsRepository productsRepository = ProductsRepository();
          final BookTimeSlotRepository bookTimeSlotRepository =
              BookTimeSlotRepository();
          final SessionRepository sessionRepository =
              SessionRepository(pref: LocalPref());
          final SeatSlotRepository seatSlotRepository = SeatSlotRepository();*/

          return MultiRepositoryProvider(
            providers: [
              RepositoryProvider<UserRepository>(
                  create: (context) => userRepository),
              /*RepositoryProvider<TimerRepository>(
                  create: (context) => timerRepository),
              RepositoryProvider<ProductsRepository>(
                  create: (context) => productsRepository),
              RepositoryProvider<HomeRepository>(
                  create: (context) => homeRepository),
              RepositoryProvider<ShowRepository>(
                  create: (context) => showRepository),
              RepositoryProvider<BookTimeSlotRepository>(
                  create: (context) => bookTimeSlotRepository),
              RepositoryProvider<SessionRepository>(
                  create: (context) => sessionRepository),
              RepositoryProvider<SeatSlotRepository>(
                  create: (context) => seatSlotRepository),*/
            ],
            child: MultiBlocProvider(
              providers: [
                BlocProvider(
                  create: (context) =>
                      AuthenticationBloc(userRepository: userRepository)
                        ..add(AppStarted()),
                ),
                BlocProvider(
                  create: (context) => HomeBloc(
                    homeRepository: homeRepository,
                    userRepository: userRepository,
                  ),
                ),
                BlocProvider(
                  create: (context) =>
                      LoginBloc(userRepository: userRepository),
                )
              ],
              child: MyApp(),
            ),
          );
        }

        return Container();
      },
    );
  }
}
