import 'package:etramite_flutter/clases/SharedPref.dart';
import 'package:etramite_flutter/screens/LoginScreen.dart';
import 'package:etramite_flutter/services/apiService.dart';
import 'package:etramite_flutter/services/toastService.dart' as toast;
import 'package:flutter/material.dart';

Future<dynamic> getLoginDB(BuildContext context, usuario, password) async {
  var snapshot = await ApiService().post(
      'login', null, {'username': usuario, 'password': password}).then((resp) {
    var respuesta = resp?.statusCode;
    // print('response $respuesta');
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      ///print("cuerpo de la respuesta post a  ${resp?.statusMessage}");
      var data = resp?.data;
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado, credenciales inválidas");
      }
      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexión");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> getLoginGoogle(BuildContext context, token) async {
  var snapshot = await ApiService().post(
    'login/google',
    {'googleIdToken': token},
    {'googleIdToken': token},
  ).then((resp) {
    var respuesta = resp?.statusCode;
    //print('response $respuesta');
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta post a  ${resp?.statusMessage}");
      var data = resp?.data;
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado, credenciales inválidas");
      }
      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexión");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> registrarse(BuildContext context, dynamic body) async {
  var snapshot =
      await ApiService().post('registrarse', null, body).then((resp) {
    var respuesta = resp?.statusCode;
    //print('response $respuesta');
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta post a  ${resp?.statusMessage}");
      var data = resp?.data;
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexión");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> recuperarPass(BuildContext context, email) async {
  var snapshot =
      await ApiService().post('resetpass', null, {'email': email}).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta post a  ${resp?.statusMessage}");
      var data = resp?.data;
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      if (resp?.data != null) {
        print('retornara solo data');
        return resp?.data;
      }
      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<void> logout(BuildContext context) async {
  var snapshot = await ApiService().get('login', {'logout': null}).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError(
        "Verifique su conexión e intente de nuevo.",
      );
    }
    if (respuesta == 200) {
      //Navigator.of(context, rootNavigator: true).push(context, '/home');
      //print("cuerpo de la respuesta post a  ${resp?.statusMessage}");
      goLoginPage(context);
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

goLoginPage(BuildContext context) async {
  await sharedPrefs.save('login', 'no');
  Navigator.of(context).pushAndRemoveUntil(
    MaterialPageRoute<void>(
      builder: (BuildContext context) => const LoginScreen(),
    ),
    (Route<dynamic> route) => false,
  );
}
//Navigator.of(context).pushNamed(RoutePaths.Login);