import 'dart:convert';
import 'dart:io';
import 'package:etramite_flutter/services/apiService.dart';
import 'package:etramite_flutter/services/authService.dart';
import 'package:etramite_flutter/services/fileStorage.dart';
import 'package:flutter/material.dart';
import 'package:etramite_flutter/services/toastService.dart' as toast;

Future<dynamic> listaTramitesDisponibles(BuildContext context) async {
  var snapshot = await ApiService().get('tipos-tramites/suggest',
      {'soloActivos': 'S', 'iDisplayLength': 1000}).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      /*if (respuesta >= 500) {
        toast.showToastError("Problemas en el servidor", context, duration: 3);
      }*/

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> listaMatriculas(BuildContext context, dynamic? institu) async {
  //print('institucion $institu');
  var snapshot = await ApiService()
      .get('alummatrics', {'institucionId': institu}).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      /*if (respuesta >= 500) {
        toast.showToastError("Problemas en el servidor", context, duration: 3);
      }*/

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> listaCiudades(BuildContext context, String? search) async {
  var snapshot = await ApiService().get('ciudades-etramite/suggest',
      {'iDisplayLength': 20, 'sSearch': search}).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      /*if (respuesta >= 500) {
        toast.showToastError("Problemas en el servidor", context, duration: 3);
      }*/

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> listaColegios(BuildContext context, String? search) async {
  var snapshot = await ApiService().get('colegios-ealu/suggest',
      {'iDisplayLength': 20, 'sSearch': search}).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      /*if (respuesta >= 500) {
        toast.showToastError("Problemas en el servidor", context, duration: 3);
      }*/

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> listaInstituciones(BuildContext context, String? search) async {
  var snapshot = await ApiService().get('instituciones/suggest',
      {'iDisplayLength': 20, 'iSortCol_0': 1, 'sSearch': search}).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      /*if (respuesta >= 500) {
        toast.showToastError("Problemas en el servidor", context, duration: 3);
      }*/

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> listaTramitesDocs(BuildContext context, dynamic? id) async {
  //print('institucion $institu');
  var snapshot = await ApiService()
      .get('tipos-tramites-reqs/by-tipo-tramite/$id', null)
      .then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      /*if (respuesta >= 500) {
        toast.showToastError("Problemas en el servidor", context, duration: 3);
      }*/

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<void> downloadTramiteArchivo(
    BuildContext context, idTramite, filename) async {
  var savePath = await getSavePath(context) + "/$filename";
  var response = await ApiService()
      .download('/mis-tramites/tipodoc/formato/$idTramite', 2, savePath);
  //print(response!.headers);
  var data = response!.data.toString().replaceAll('"', '').replaceAll('\n', '');
  var bytes = base64Decode(data);
  try {
    File file = File(savePath);
    var raf = file.openSync(mode: FileMode.write);
    raf.writeFromSync(bytes);
    await raf.close();
  } catch (e) {
    print(e);
  }
}

Future<dynamic> saveNewTramite(BuildContext context, dynamic data) async {
  var snapshot =
      await ApiService().post('mis-tramites', null, data).then((resp) {
    //print('response ${resp?.data}');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    print(resp);
    if (respuesta == 201) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
      if (respuesta! > 401 || respuesta < 401) {
        return resp?.data;
      }

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}
