import 'dart:io';

import 'package:etramite_flutter/clases/ConectionApi.dart';
import 'package:etramite_flutter/services/apiService.dart';
import 'package:etramite_flutter/services/authService.dart';
import 'package:flutter/material.dart';
import 'package:etramite_flutter/services/toastService.dart';

Future<ImageProvider> getFoto(context, imgPath) async {
  var cookie = await ConectionApi().getCookie();
  Map<String, String> headersMap = {'cookie': cookie.first.toString()};
  //print(headersMap);
  if (imgPath != '') {
    return FileImage(
      File(imgPath),
    );
  }
  return NetworkImage(
    'https://tramites.una.py/etramite-backend/perfil/foto.png',
    headers: headersMap,
    /*fit: BoxFit.cover,
    errorBuilder:
        (BuildContext context, Object exception, StackTrace? stackTrace) {
      return Image.asset(
        'assets/foto_error.png',
        fit: BoxFit.cover,
      );
    },*/
  );
}

Future<dynamic> getDatosPersonales(BuildContext context) async {
  var snapshot = await ApiService().get('perfil', null).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        showToastError("No autorizado");
        goLoginPage(context);
      }
      /*if (respuesta >= 500) {
        toast.showToastError("Problemas en el servidor", context, duration: 3);
      }*/

      return null;
    }
  }).catchError((error) {
    showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> setActualizarDatosPersonales(
    BuildContext context, dynamic datos) async {
  var snapshot = await ApiService()
      .post('perfil/actualizar-datos', null, datos)
      .then((resp) {
    print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      if (data['success'] == true) {
        showToastSuccess(data['successMessage']);
      }
      return data;
    } else {
      if (respuesta == 401) {
        showToastError("No autorizado");
        goLoginPage(context);
      }
      /*if (respuesta >= 500) {
        toast.showToastError("Problemas en el servidor", context, duration: 3);
      }*/

      return null;
    }
  }).catchError((error) {
    showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> actualizarContrasenha(
    BuildContext context, dynamic datos) async {
  var snapshot = await ApiService()
      .post('perfil/cambiar-contrasenha', null, datos)
      .then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        showToastError("No autorizado");
        goLoginPage(context);
      }

      /*if (respuesta >= 500) {
        toast.showToastError("Problemas en el servidor", context, duration: 3);
      }*/

      return null;
    }
  }).catchError((error) {
    showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}
