import 'dart:convert';
import 'dart:io';
import 'package:etramite_flutter/services/fileStorage.dart';
import 'package:flutter/material.dart';
import 'package:etramite_flutter/services/apiService.dart';
import 'package:etramite_flutter/services/toastService.dart' as toast;
import 'authService.dart';

Future<dynamic> info(BuildContext context) async {
  var snapshot =
      await ApiService().get('/core-session/info', null).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexión");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> cambiarInstitucion(BuildContext context, id) async {
  var snapshot = await ApiService()
      .get('cambiar-institucion', {'institucion': id}).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexión");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> listarTramites(
    BuildContext context, int start, int len, String search) async {
  var snapshot = await ApiService().get('mis-tramites/datatable',
      {'start': start, 'length': len, 'search': search}).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> tramiteDetalle(BuildContext context, id) async {
  var snapshot = await ApiService().get('mis-tramites/$id', null).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexión");
    print(error);
    return null;
  });
  return snapshot;
}

Future<List<dynamic>> observacionTipoTramite(BuildContext context, id) async {
  var snapshot = await ApiService()
      .get('tipos-tramites-obs/by-tipo-tramite/$id', null)
      .then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print('data $data');
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }
    }
    return null;
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> comentariosTramite(BuildContext context, id) async {
  var snapshot = await ApiService()
      .get('tramites-comentarios/by-tramite/$id', null)
      .then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> enviarComentarioTramite(BuildContext context, data) async {
  var snapshot =
      await ApiService().post('tramites-comentarios', null, data).then((resp) {
    //print('response $resp');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 201) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      toast.showToastSuccess("Comentario Enviado");
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> eliminarComentarioTramite(
    BuildContext context, dynamic id) async {
  var snapshot =
      await ApiService().delete('tramites-comentarios/$id', null).then((resp) {
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 204) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      //var data = resp?.data;
      //print(resp);
      return {'successMessage': "Comentario borrado con éxito"};
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<void> downloadTramiteArchivoAdjunto(
    BuildContext context, idTramite, hash, filename) async {
  var savePath = await getSavePath(context) + "/$filename";
  //print(savePath);
  var response = await ApiService()
      .download('public-docsadjuntos/$idTramite/$hash', 1, savePath);
  //print(response!.headers);
  var data = response!.data.toString().replaceAll('"', '').replaceAll('\n', '');
  var bytes = base64Decode(data);
  try {
    File file = File(savePath);
    var raf = file.openSync(mode: FileMode.write);
    raf.writeFromSync(bytes);
    await raf.close();
  } catch (e) {
    print(e);
  }
}

Future<dynamic> cambiarArchivoAdjunto(dynamic data) async {
  var snapshot = await ApiService()
      .post('mis-docsadjuntos/cambiar', null, data)
      .then((resp) {
    print('response ${resp}');
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 200) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      var data = resp?.data;
      //print(resp);
      return data;
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
      }
      if (resp!.data != null) {
        toast.showToastError(resp.data['errorMessage']);
      }
      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}

Future<dynamic> eliminarTramite(BuildContext context, dynamic id) async {
  var snapshot =
      await ApiService().delete('mis-tramites/$id', null).then((resp) {
    var respuesta = resp?.statusCode;
    if (respuesta != null && respuesta < 200) {
      toast.showToastError("Verifique su conexión e intente de nuevo.");
    }
    if (respuesta == 204) {
      //print("cuerpo de la respuesta get a  ${resp?.statusMessage}");
      //var data = resp?.data;
      //print(resp);
      return {'successMessage': "Trámite borrado con éxito"};
    } else {
      if (respuesta == 401) {
        toast.showToastError("No autorizado");
        goLoginPage(context);
      }

      return null;
    }
  }).catchError((error) {
    toast.showToastError("Verifique su conexion");
    print(error);
    return null;
  });
  return snapshot;
}
